#!/usr/bin/env python
# setup.py generated by flit for tools that don't yet use PEP 517

from distutils.core import setup

packages = \
['pyprocessors_search_segments']

package_data = \
{'': ['*']}

install_requires = \
['pymultirole-plugins>=0.5.0,<0.6.0',
 'sherpa-client==0.12.1',
 'tenacity==8.1.0']

extras_require = \
{'dev': ['flit', 'pre-commit', 'bump2version'],
 'docs': ['sphinx',
          'sphinx-rtd-theme',
          'm2r2',
          'sphinxcontrib.apidoc',
          'jupyter_sphinx'],
 'test': ['pytest>=7.0.0',
          'pytest-cov',
          'pytest-flake8',
          'pytest-black',
          'flake8==3.9.2',
          'tox',
          'dirty-equals',
          'werkzeug==2.0.0',
          'flask==2.1.3']}

entry_points = \
{'pyprocessors.plugins': ['search_segments = '
                          'pyprocessors_search_segments.search_segments:SearchSegmentsProcessor']}

setup(name='pyprocessors-search_segments',
      version='0.5.30',
      description='Similar segments processor',
      author='Olivier Terrier',
      author_email='olivier.terrier@kairntech.com',
      url='https://kairntech.com/',
      packages=packages,
      package_data=package_data,
      install_requires=install_requires,
      extras_require=extras_require,
      entry_points=entry_points,
      python_requires='>=3.8',
     )
